import { CkDistribution, CkFargateCluster, CkFargateService, CkFargateTaskDefinition, CkPublicApplicationLoadbalancer, CkVpc } from '@cloudkitect/components';
import * as ec2 from 'aws-cdk-lib/aws-ec2';
import * as ecs from 'aws-cdk-lib/aws-ecs';
import * as elbv2 from 'aws-cdk-lib/aws-elasticloadbalancingv2';
import { Construct } from 'constructs';
/**
 * Serverless container app properties
 */
export interface CkServerlessContainerAppsProps {
    /**
       * Domain name
       * @example cloudkitect.com
       */
    readonly ckDomainName: string;
    /**
       * Subdomain is usually the name of the microservice application such as user-app, account-app etc.
       * @default app
       */
    readonly ckSubDomain?: string;
}
/**
 * Properties that are used to customize the service.
 * You can add multiple services behind the load balancer using addService() method
 * and passing these properties for customization.
 */
export interface CkServiceProps {
    /**
       * Service name e.g. UserService, FileService etc.
       */
    readonly ckServiceName: string;
    /**
       * Container image used for the task definition
       */
    readonly ckImage: ecs.ContainerImage;
    /**
       * Priority of the service within the load balancer routing
       * @default 1
       */
    readonly ckServicePriority?: number;
    /**
       * Service Path e.g /user or /account
       * @default /
       */
    readonly ckPathPattern?: string;
    /**
       * Health check path
       * @default /
       */
    readonly ckHealthCheckPath?: string;
    /**
       * Port at which container listens for requests
       * @default 80
       */
    readonly ckContainerPort?: number;
}
/**
 * Information regarding how the service is configured, can be used to customize certain aspects of the service
 */
export interface ServiceConfig {
    /**
       * Fargate task definition
       */
    readonly fargateTaskDefinition: CkFargateTaskDefinition;
    /**
       * Fargate security group
       */
    readonly fargateSecurityGroup: ec2.SecurityGroup;
    /**
       * Fargate ECS Service
       */
    readonly ecsService: CkFargateService;
    /**
       * Container Definition
       */
    readonly containerDef: ecs.ContainerDefinition;
}
/**
 * CloudKitect Serverless Container App
 */
export declare class CkServerlessContainerApps extends Construct {
    /**
       * VPC where ECS cluster is launched
       */
    readonly vpc: CkVpc;
    /**
       * ECS fargate cluster
       */
    readonly fargateCluster: CkFargateCluster;
    /**
       * Publicly accessible Application Load Balancer
       */
    readonly publicAlb: CkPublicApplicationLoadbalancer;
    /**
       * Https Listener configured for the public ALB
       */
    readonly httpsListener?: elbv2.ApplicationListener;
    /**
       * CloudFront distribution created for sending traffic to load balancer
       */
    readonly cloudFront: CkDistribution;
    constructor(scope: Construct, id: string, props: CkServerlessContainerAppsProps);
    /**
       * Adds a Microservice as a new ECS Service to the cluster
       * It will have its own TaskDefinition and will run as a task managed by ECS Service
       * @param props
       */
    addService(props: CkServiceProps): ServiceConfig;
}
