import { CkBucket, CkBucketProps, CkDistribution } from '@cloudkitect/components';
import * as cloudfront from 'aws-cdk-lib/aws-cloudfront';
import * as route53 from 'aws-cdk-lib/aws-route53';
import * as s3deploy from 'aws-cdk-lib/aws-s3-deployment';
import { Construct } from 'constructs';
/**
 * CloudKitect Serverless Website Pattern Properties
 */
export interface CkServerlessWebsiteProps {
    /**
       * Domain name
       */
    readonly ckDomainName: string;
    /**
       * Subdomain name e.g. www
       * @default www
       */
    readonly ckSubdomain?: string;
    /**
       * Location of website content
       */
    readonly ckPathToContent: string;
    /**
       * Root object of the website, e.g. index.html
       * @default index.html
       */
    readonly ckDefaultRootObject?: string;
    /**
       * Additional bucket policy actions
       * @default s3:GetObject
       */
    readonly ckBucketPolicyActions?: string[];
    /**
       * Bucket properties to override defaults
       */
    readonly ckBucketProps?: CkBucketProps;
    /**
       * Origin Access Identity to override defaults
       * @default A new one is created
       */
    readonly ckOriginAccessIdentity?: cloudfront.OriginAccessIdentity;
    /**
       * Flag to enable or disable CloudFront logging
       * @default false
       */
    readonly ckEnableCloudFrontLogging?: boolean;
    /**
       * Override default CloudFront Distribution behavior
       */
    readonly ckCloudFrontDistributionDefaultBehavior?: cloudfront.BehaviorOptions;
    /**
       * Hosted zone properties
       */
    readonly ckHostedZone?: route53.IHostedZone;
}
/**
 * CloudKitect Serverless Website Pattern Properties
 *
 * ### Infrastructure Diagram
 *
 * ### Default Configuration
 * Validated public certificate for the API domain
 * Cloudfront Distribution
 *
 * Note: This construct expects a HostedZone present in the same AWS account
 *
 * ### Default Alarms
 * Available only in Enhanced components
 *
 * ### Logging and Monitoring
 * Available only in Enhanced components
 *
 *
 * ### Examples
 * Default Usage, if HostedZone is in the same account
 * ```ts
 * new CkServerlessWebsite(this, "LogicalId", {
 *      ckDomainName: 'example.com',
 *      ckSubdomain: "www",
 *      ckPathToContent: './site-content'
 * });
 * ```
 *
 * ### Compliance
 * It addresses the following compliance requirements
 * 1. Blocks public access
 *    >  - Risk Level: Medium
 *    >  - Compliance: PCI, HIPAA, GDPR, APRA, MAS, NIST4
 *    >  - Well Architected Pillar: Security
 * 2. Block S3 Bucket Public 'READ' Access
 *    >  - Risk Level: Very High
 *    >  - Compliance: PCI, GDPR, ARPA, MAS, NIST4
 *    >  - Well Architected Pillar: Security
 * 3. Only allow secure transport protocols
 *    >  - Risk Level: High
 *    >  - Compliance: PCI, APRA, MAS, NIST4
 *    >  - Well Architected Pillar: Security
 * 4. Server side encryption
 *    >  - Risk Level: High
 *    >  - Compliance: PCI, HIPAA, GDPR, APRA, MAS, NIST4
 *    >  - Well Architected Pillar: Security
 * 5. S3 Bucket Block ACLs
 *    >  - Risk Level: Very High
 *    >  - Compliance: PCI, APRA, MAS, NIST4
 *    >  - Well Architected Pillar: Security
 * 6. Cloudfront origin should not use insecure protocols
 *    >  - Risk Level: Medium
 *    >  - Compliance: PCI, HIPAA, APRA, MAS, NIST4
 *    >  - Well Architected Pillar: Security
 * 7. Cloudfront uses enhanced security policy min TLS1.2
 *    >  - Risk Level: High
 *    >  - Compliance: PCI, HIPAA, MAS, NIST4
 *    >  - Well Architected Pillar: Security
 * 8. Cloudfront uses only secure protocol to communicate with origin
 *    >  - Risk Level: Medium
 *    >  - Compliance: PCI, HIPAA, APRA, MAS, NIST4
 *    >  - Well Architected Pillar: Security
 * 9. Cloudfront uses only secure protocol to communicate with end users
 *    >  - Risk Level: High
 *    >  - Compliance: PCI, HIPAA, NIST4
 *    >  - Well Architected Pillar: Security
 * 10. Enable origin access identify for S3 origins
 *    >  - Risk Level: Medium
 *    >  - Compliance: NA
 *    >  - Well Architected Pillar: Security
 */
export declare class CkServerlessWebsite extends Construct {
    /**
       * Bucket hosting website content
       */
    readonly websiteBucket: CkBucket;
    /**
       * Origin Access Identity
       */
    readonly cloudfrontOAI: cloudfront.OriginAccessIdentity;
    /**
       * CloudFront distribution used in this construct
       */
    readonly cdn: CkDistribution;
    /**
       * Bucket deployment
       */
    readonly bucketDeployment: s3deploy.BucketDeployment;
    constructor(scope: Construct, name: string, props: CkServerlessWebsiteProps);
    getDistributionDomains(props: CkServerlessWebsiteProps): string[];
    getSiteDomain(props: CkServerlessWebsiteProps): string;
    getSanCertificateDomains(props: CkServerlessWebsiteProps): string[];
}
